/* Define to 1 if have PostgreSQL header files.  */
#undef HAVE_LIBPQ_FE_H

/* Define to 1 if sys/sem.h defines `union semun' type.  */
#undef HAVE_SEMUN

/* Define to 1 if g++ is available.  */
#undef HAVE_GXX

/* Define to 1 if bitmaps are used.
   With bitmaps, each memory access is checked.
   Without, Checker provides only a bullet-proof memory allocator with
   garbage detector.  */
#undef HAVE_BITMAPS
